'use strict';

const Os = require('os');
const Path = require('path');
const Kill = require('./lib/kill');
const Cluster = require('cluster');

module.exports = class Apiss {

	constructor (data) {
		data = data || {};

		if (process.env.DEV) {
			this.path = Path.join(__dirname, 'test', 'vhosts');
		} else {
			this.path = Path.resolve(data.path) || Path.join(Os.homedir(), '.apiss', 'vhosts');
		}

		this.workers = [];
		this.port = data.port || 0;
		this.host = data.host || 'localhost';
		this.instances = data.instances || Os.cpus().length;

		this.env = {
			PORT: this.port,
			HOST: this.host,
			PATH: this.path,
			DEV: process.env.DEV
		};

		Cluster.setupMaster({
			exec: Path.join(__dirname, './lib/worker.js')
		});

	}

	async open  () {
		if (!this.workers.length) {
			for (let i = 0; i < this.instances; i++) {
				let worker = Cluster.fork(this.env);
				this.workers.push(worker);
			}
		}
	}

	async close () {
		let worker;

		while (worker = this.workers.shift()) {
			await Kill(worker.process.pid, 'SIGKILL');
		}

	}

};
