'use strict';

const Fs = require('fs');
const Util = require('util');
const Path = require('path');

const ReadFolder = Util.promisify(Fs.readdir);

module.exports = async function (data) {
	const result = [];

	const host = data.host;
	const path = Path.resolve(data.path);

	const routeFolders = await ReadFolder(path);

	for (const routeFolder of routeFolders) {

		const routeFolderPath = Path.join(path, routeFolder);
		const routeFiles = await ReadFolder(routeFolderPath);
		const virtualHost = `${routeFolder.replace('.', '')}.${host}`;

		const routeFilePath = Path.join(routeFolderPath, 'index.js');
		const routes = require(routeFilePath);

		for (const route of routes) {

			if (!route.vhost) {
				route.vhost = virtualHost;
			} else if (route.vhost.constructor === String) {
				route.vhost = [route.vhost, virtualHost];
			} else if (route.vhost.constructor === Array) {
				route.vhost = route.vhost.push(virtualHost);
			}

			route.options = route.options || {};
			route.options.cors = route.options.cors || {};
			route.options.cors.origin = route.options.cors.origin || [];
			route.options.cors.origin.push(routeFolder);
			result.push(route);

		}

	}

	return result;
};
